**CMS files generated with cms-explorer** http://code.google.com/p/cms-explorer/
use the provided lists for q&d but cms explorer does a lot more. 

**wordpress.fuzz.txt**
generated by bringing the filenames from each incremental new version of wordpress into one fuzzfile
